def parse_qwack_file(file_path):
    metadata_blocks = {}
    current_block = None

    with open(file_path, 'r') as file:
        for line in file:
            line = line.strip()

            # Skip comments (lines starting with '&')
            if line.startswith('&'):
                continue

            # Check if it's a metadata block
            if line.startswith('@'):
                current_block = line.split('{')[0].strip('@')
                metadata_blocks[current_block] = {}
            elif line.startswith('$'):
                sub_object_name = line.split('{')[0].strip('$')
                current_block = f"{current_block}${sub_object_name}"
                metadata_blocks[current_block] = {}
            elif line.startswith('}'):
                current_block = None
            elif '|' in line:
                name, value = line.split('|')
                name = name.strip()
                value = value.strip()
                existing_value = metadata_blocks[current_block].get(name)
                if existing_value:
                    if not isinstance(existing_value, list):
                        metadata_blocks[current_block][name] = [existing_value]
                    metadata_blocks[current_block][name].append(value)
                else:
                    metadata_blocks[current_block][name] = value

    return metadata_blocks

def get_value(parsed_data, metadata_path):
    # Split the metadata path into parts based on brackets
    metadata_parts = metadata_path.split('[')

    # Extract the object type and object name
    object_type = metadata_parts[0].strip('@')
    object_name = metadata_parts[1].strip(']')

    # Get the value based on the metadata path
    current_data = parsed_data
    for part in metadata_parts[2:]:
        if part.startswith('$'):
            current_data = current_data.get(part.strip(']$'), {})
        else:
            current_data = current_data.get(part.strip(']'), {})

    return current_data.get(object_type, {}).get(object_name, None)